%diesel_vs_otto
% Plots a surface graph comparing the efficiency of disel vs otto heat
% engines.
%
% LAST UPDATED by Andy French 29/10/15

%Define compression ratios r = V1/V2 (Otto and Diesel), s = V3/V2 (Diesel)
%s = 1 (Otto)
rmax = 10;
smax = 10;
r = linspace( 1, rmax, 500 );
s = linspace( 1, smax, 500 );

%Specific heat capacity 'alpha parameter' i.e. number of degrees of freedom
%of molecular motion. A non integer number can be used as an empirical
%correction to make a more exact specific heat capacity.
alpha = 3;

%Fontsize
fsize = 16;

%Gamma parameter (ratio of isobaric and isochoric specific heat capacities)
y = 1 + 2/alpha;

%Define efficiencies nu = W/Q_in = Work done / Heat input
nu_otto = 1 - 1./(r.^(y-1));
[rr,s] = meshgrid(r,s);
nu_diesel = 1 - ( s.^y - 1 )./(( rr.^(y-1) ).*y.*(s-1) );

%r>s since V1 > V3 > V2
nu_diesel( rr <= s ) = NaN; 

%Plot heat engine efficiencies

%Diesel
subplot(2,1,1);
surf(rr,s,nu_diesel);
shading interp;
view(2);
colorbar('location','northoutside');
ylabel('s = V_3 / V_2','fontsize',fsize)
title('Diesel cycle efficiency \eta = W/Q_{in}','fontsize',fsize)
xlim([1,rmax])
ylim([1,smax])
set(gca,'fontsize',fsize)
caxis([0,1])

%Otto
subplot(2,1,2);
plot(r,nu_otto);
xlabel('r = V_1/V_2','fontsize',fsize);
ylabel('\eta','fontsize',fsize)
title('Otto cycle efficiency \eta = W/Q_{in}','fontsize',fsize)
xlim([1,rmax])
ylim([0,1])
set(gca,'fontsize',fsize)
grid on

%Print and close figure
print( gcf,'otto vs diesel.png','-r300','-dpng' );
close(gcf);

%End of code